=Test of bullets

* dot2

> 

* dot01

* dot01

>

# second level (dot01)


<2

* top: dot2 bu

=page 2

This tests shift levels

* dot2

>

* dot01


Text should not be indented ...

=page 3

The following list should start at level 1

* item1: dot2

* item2: dot2
