<center>
<table border=0 cellpadding=0 cellspacing=0>

  <tr>

    <td>
    <table border=0 cellpadding=0 cellspacing=0>
      <tr>
      <td class=mmtop background="IMAGE_REF/MM-Blau.jpg">
        <a href="URL_NEXT">HEADLINE
        </a>
      </td>
      <td class=mmtop background="IMAGE_REF/MM-Verlauf-blau.jpg"></a>
        <a href="URL_NEXT">
        &nbsp;&nbsp;
        &nbsp;&nbsp;
        &nbsp;&nbsp;
        &nbsp;&nbsp;
        &nbsp;&nbsp;
        &nbsp;&nbsp;
        &nbsp;&nbsp;
      </td>
      </tr>
    
      <tr><td><img src="IMAGE_REF/MM-linespace.gif"></td></tr>

      <tr>
      <td>
        <a href="URL_PREV">
        <img border=0 src="IMAGE_REF/MM-Grau.jpg"></a>
      </td>
      <td>
        <a href="URL_PREV">
        <img border=0 src="IMAGE_REF/MM-Verlauf-grau.jpg"></a>
      </td>
      </tr>
    </table>
    </td>

    <td>
        <a href="javascript:Nav('top_SLIDE_PREFIX0000.SLIDE_SUFFIX', 'SLIDE_PREFIX0000.SLIDE_SUFFIX', 'bot_SLIDE_PREFIX0000.SLIDE_SUFFIX')">
        <img border=0 src="IMAGE_REF/MM-Logo-Rechts-Oben.jpg"></a>
    </td>
  </tr>

</table>
</center>
