<center>
<table border=0 cellpadding=0 cellspacing=0>

  <tr>

    <td>
      <table border=0 cellpadding=0 cellspacing=0>
        <tr>
          <td class=mmtop >
            <a href="URL_NEXT">HEADLINE </a>
          </td>
          <td class=mmtop ></a>
            <a href="URL_NEXT">
            &nbsp;&nbsp;
            &nbsp;&nbsp;
            &nbsp;&nbsp;
            &nbsp;&nbsp;
            &nbsp;&nbsp;
            &nbsp;&nbsp;
            &nbsp;&nbsp;
          </td>
          <td align="right">
            <a href="javascript:Nav('top_SLIDE_PREFIX0000.SLIDE_SUFFIX', 'SLIDE_PREFIX0000.SLIDE_SUFFIX', 'bot_SLIDE_PREFIX0000.SLIDE_SUFFIX')">
            <img border=0 src="IMAGE_REF/Netexpress.jpg"></a>
          </td>
        </tr>
    
    <!--
        <tr><td><img src="IMAGE_REF/NE-linespace.gif"></td></tr>
        -->

        <tr>
          <td colspan=3 >
            <a href="URL_PREV">
              <img border=0 src="IMAGE_REF/NE-Balken.jpg"></a>
          </td>
        </tr>
      </table>
    </td>

  </tr>

</table>
</center>
