<!-- ---- Bottom Navigation Bar ---------------------------------- BEGIN 
  $Id: big_blue-bot.tpl,v 1.2 2001/12/06 21:38:12 lorenz Exp $
-------------------------------------------------------------------- -->
<HR SIZE=8>

</FONT>
<TABLE WIDTH=100%  BORDER=0 CELLSPACING=0 CELLPADDING=2>
<TR>

  <TD  WIDTH=10%>
     LABEL_NEXT:<br>
     LABEL_PREV:<br>
     LABEL_CONTENTS:<br> 
     LABEL_INDEX:<br> 
  </TD>
  <TD >
     <a href="URL_NEXT">TXT_NEXT</a><br>
     <a href="URL_PREV">TXT_PREV</a><br>
     <a href="URL_CONTENTS">TXT_CONTENTS</a><br> 
     <a href="URL_INDEX">TXT_INDEX</a><br> 
  </TD>
 <TD VALIGN=top ALIGN=right ><SMALL>
    BOT_RIGHT_TXT
    </SMALL>
 </TD>

</TR>
</TABLE>
<!-- ---- Bottom Navigation Bar -------------------------------- END -->
