
// Test of localtoc

=Chapter One

\LOCALTOC{type="linked"}

==Overview

This is overview of Chapter One

==Introduction

This is the intro in Chapter One.


=Chapter Two

\LOCALTOC{type="linked" depth=1}

some other text ...

==sub one of chapter 2

\LOCALTOC{type="linked"}

===Overview

This is overview in subchapter one of chapter 2

===Tests

Tests in sub chapter one of ch. 2

===Advantages

kkkk

====Advantages 1

111

====Advantages 2

222

==sub two of chapter 2

sub section two of ch. 2

=Chapter Three

\LOCALTOC{type="linked"}

==Overview

overview in Chapter Tree

==Tests

This is another test page in chapter three.
