
=Empty Table Fields

@|
 Head1 | 
       | xx
    zz |

text

=Table with Table Tag

\TABLE{separator=";" head_bgcolor="#CC0000" bgcolor="#CCCCCC" border=3}
kkk | uuu ; vvv ; ggg
RRRR      ; xx  ; ii
\END_TABLE
