
// Test of tags

=\U<Tags> \B<in> \SUB<a> \I<fancy> \C<headline>

Text with \B<bold>, \I<italic>, \C<code>, \SUB<sub>- and
\SUP<superscript>, \U<underlined>

*Text with \B<bold>, \I<italic>, \C<code>, \SUB<sub>- and
\SUP<superscript>, \U<underlined>


 Text with \B<bold>, \I<italic>, \C<code>, \SUB<sub>- and
 \SUP<superscript>, \U<underlined>

=Even \F{color=green}<more> Tags

Color \F{color=red}<tag>
Color \F{color="#ffff99" face=Arial}<tag>
Color \F{color=red size="+2"}<tag>

*Color \F{color=red}<tag>

*Color \F{color=red size="+2"}<tag>

*Color \F{color="#ffff99" face=Arial}<tag>

 Color \F{color=red}<tag>
 Color \F{color="#ffff99" face=Arial}<tag>
 Color \F{color=red size="2"}<tag>
