

// Test of escapes

=\I<Escapes> in  \E<Uuml>berschrift

Simple \B<text>: 
Some German Umlaute: ähnlich, über, möglich, Ähnlichkeit,
Überflieger, Öffnungszeit.

Some German Umlaute: \E<auml>hnlich, \E<uuml>ber, m\E<ouml>glich, 
\E<Auml>hnlichkeit, \E<Uuml>berflieger, \E<Ouml>ffnungszeit.


=Noch andere \B<Escapes> in  Überschrift

*Simple \B<text>: 
Some German Umlaute: ähnlich, über, möglich, Ähnlichkeit,
Überflieger, Öffnungszeit.

*Some German Umlaute: \E<auml>hnlich, \E<uuml>ber, m\E<ouml>glich, 
\E<Auml>hnlichkeit, \E<Uuml>berflieger, \E<Ouml>ffnungszeit.



=\B<More Escapes> \C<in> \E<Uuml>berschrift

Text

 Simple \B<text>: 
 Some German Umlaute: ähnlich, über, möglich, Ähnlichkeit,
 Überflieger, Öffnungszeit.

 Some German Umlaute: \E<auml>hnlich, \E<uuml>ber, m\E<ouml>glich, 
 \E<Auml>hnlichkeit, \E<Uuml>berflieger, \E<Ouml>ffnungszeit.



