
+GREEN:\F{color=green}<__body__>

=Read Notes

xx

=Colored References

\GREEN<\REF{type=linked name="Read Notes"}<\C<read notes (no color)>>>

\C<\REF{type=linked name="Read Notes"}<\GREEN<read notes (green)>>>
