<html>
  <!--
  $Id: mixed-mode-frm.tpl,v 1.2 2001/12/06 21:38:12 lorenz Exp $
  $Revision: 1.2 $
  $Date: 2001/12/06 21:38:12 $
  -->
<head>
  <title>TITLE</title>
</head>

<frameset border=0 frameborder=0 framespacing=0 rows="120, *, 50">
    <frame src="./top_SLIDE_PREFIX0000.SLIDE_SUFFIX" name="Top">
    <frame src="mixed-mode-title.htm" name="Data">
    <frame src="./mixed-mode-bot.htm" name="Foot">
</frameset>

<body>
  Please call the <a href="SLIDE_PREFIX0000.SLIDE_SUFFIX">titel page</a>
</body>
</html> 
